==> mdm-rpc-0.1.124-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/FranchiserOrgRelationVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;

/**
* @author zhangqiang:
* @version 创建时间：2017年11月16日 上午11:26:47
* 经销商、分公司大区对应关系
*/
public class FranchiserOrgRelationVo implements Serializable{
	//经销商编码
	private String franchiserCode;
	//经销商名称
	private String franchiserName;
	//经销商类型
	private String franchiserType;
	//是否主账号
	private String isMaster;
	//对应经销商主账号编码
	private String masterCustomerCode;
	//主账号经销商名称
	private String masterCustomerName;
	//分公司编码（sd编码）
	private String sdOrgCode;
	//分公司编码（HR编码）
	private String hrOrgCode;
	//分公司名称
	private String orgName;
	//大区编码（sd编码）
	private String sdRegionCode;
	//大区编码（HR编码）
	private String hrRegionCode;
	//大区名称
	private String regionName;
	//所在省份
	private String franchiserProvince;
	//所在地市
	private String franchiserCity;
	//所在县区
	private String franchiserDistrict;
	//销售区域省份
	private String saleareaProvince;
	//销售区域地市
	private String saleareaCity;
	//销售区域县区
	private String saleareaDistrict;
	//最后更新时间
	private java.util.Date lastUpdateDate;
	//是否老名酒-专营产品事业部
	private String flag;

	public String getFranchiserCode() {
		return franchiserCode;
	}

	public void setFranchiserCode(String franchiserCode) {
		this.franchiserCode = franchiserCode;
	}

	public String getFranchiserName() {
		return franchiserName;
	}

	public void setFranchiserName(String franchiserName) {
		this.franchiserName = franchiserName;
	}

	public String getFranchiserType() {
		return franchiserType;
	}

	public void setFranchiserType(String franchiserType) {
		this.franchiserType = franchiserType;
	}

	public String getIsMaster() {
		return isMaster;
	}

	public void setIsMaster(String isMaster) {
		this.isMaster = isMaster;
	}

	public String getMasterCustomerCode() {
		return masterCustomerCode;
	}

	public void setMasterCustomerCode(String masterCustomerCode) {
		this.masterCustomerCode = masterCustomerCode;
	}

	public String getMasterCustomerName() {
		return masterCustomerName;
	}

	public void setMasterCustomerName(String masterCustomerName) {
		this.masterCustomerName = masterCustomerName;
	}

	public String getSdOrgCode() {
		return sdOrgCode;
	}

	public void setSdOrgCode(String sdOrgCode) {
		this.sdOrgCode = sdOrgCode;
	}

	public String getHrOrgCode() {
		return hrOrgCode;
	}

	public void setHrOrgCode(String hrOrgCode) {
		this.hrOrgCode = hrOrgCode;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getSdRegionCode() {
		return sdRegionCode;
	}

	public void setSdRegionCode(String sdRegionCode) {
		this.sdRegionCode = sdRegionCode;
	}

	public String getHrRegionCode() {
		return hrRegionCode;
	}

	public void setHrRegionCode(String hrRegionCode) {
		this.hrRegionCode = hrRegionCode;
	}

	public String getRegionName() {
		return regionName;
	}

	public void setRegionName(String regionName) {
		this.regionName = regionName;
	}

	public String getFranchiserProvince() {
		return franchiserProvince;
	}

	public void setFranchiserProvince(String franchiserProvince) {
		this.franchiserProvince = franchiserProvince;
	}

	public String getFranchiserCity() {
		return franchiserCity;
	}

	public void setFranchiserCity(String franchiserCity) {
		this.franchiserCity = franchiserCity;
	}

	public String getFranchiserDistrict() {
		return franchiserDistrict;
	}

	public void setFranchiserDistrict(String franchiserDistrict) {
		this.franchiserDistrict = franchiserDistrict;
	}

	public String getSaleareaProvince() {
		return saleareaProvince;
	}

	public void setSaleareaProvince(String saleareaProvince) {
		this.saleareaProvince = saleareaProvince;
	}

	public String getSaleareaCity() {
		return saleareaCity;
	}

	public void setSaleareaCity(String saleareaCity) {
		this.saleareaCity = saleareaCity;
	}

	public String getSaleareaDistrict() {
		return saleareaDistrict;
	}

	public void setSaleareaDistrict(String saleareaDistrict) {
		this.saleareaDistrict = saleareaDistrict;
	}

	public java.util.Date getLastUpdateDate() {
		return lastUpdateDate;
	}

	public void setLastUpdateDate(java.util.Date lastUpdateDate) {
		this.lastUpdateDate = lastUpdateDate;
	}

	public String getFlag() {
		return flag;
	}

	public void setFlag(String flag) {
		this.flag = flag;
	}
	

}

==> mdm-rpc-0.1.128-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/FranchiserOrgRelationVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import java.io.Serializable;

/**
* @author zhangqiang:
* @version 创建时间：2017年11月16日 上午11:26:47
* 经销商、分公司大区对应关系
*/
public class FranchiserOrgRelationVo implements Serializable{
	//经销商编码
	private String franchiserCode;
	//经销商名称
	private String franchiserName;
	//经销商类型
	private String franchiserType;
	//是否主账号
	private String isMaster;
	//对应经销商主账号编码
	private String masterCustomerCode;
	//主账号经销商名称
	private String masterCustomerName;
	//分公司编码（sd编码）
	private String sdOrgCode;
	//分公司编码（HR编码）
	private String hrOrgCode;
	//分公司名称
	private String orgName;
	//大区编码（sd编码）
	private String sdRegionCode;
	//大区编码（HR编码）
	private String hrRegionCode;
	//大区名称
	private String regionName;
	//所在省份
	private String franchiserProvince;
	//所在地市
	private String franchiserCity;
	//所在县区
	private String franchiserDistrict;
	//销售区域省份
	private String saleareaProvince;
	//销售区域地市
	private String saleareaCity;
	//销售区域县区
	private String saleareaDistrict;
	//最后更新时间
	private java.util.Date lastUpdateDate;
	//是否老名酒-专营产品事业部
	private String flag;

	public String getFranchiserCode() {
		return franchiserCode;
	}

	public void setFranchiserCode(String franchiserCode) {
		this.franchiserCode = franchiserCode;
	}

	public String getFranchiserName() {
		return franchiserName;
	}

	public void setFranchiserName(String franchiserName) {
		this.franchiserName = franchiserName;
	}

	public String getFranchiserType() {
		return franchiserType;
	}

	public void setFranchiserType(String franchiserType) {
		this.franchiserType = franchiserType;
	}

	public String getIsMaster() {
		return isMaster;
	}

	public void setIsMaster(String isMaster) {
		this.isMaster = isMaster;
	}

	public String getMasterCustomerCode() {
		return masterCustomerCode;
	}

	public void setMasterCustomerCode(String masterCustomerCode) {
		this.masterCustomerCode = masterCustomerCode;
	}

	public String getMasterCustomerName() {
		return masterCustomerName;
	}

	public void setMasterCustomerName(String masterCustomerName) {
		this.masterCustomerName = masterCustomerName;
	}

	public String getSdOrgCode() {
		return sdOrgCode;
	}

	public void setSdOrgCode(String sdOrgCode) {
		this.sdOrgCode = sdOrgCode;
	}

	public String getHrOrgCode() {
		return hrOrgCode;
	}

	public void setHrOrgCode(String hrOrgCode) {
		this.hrOrgCode = hrOrgCode;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getSdRegionCode() {
		return sdRegionCode;
	}

	public void setSdRegionCode(String sdRegionCode) {
		this.sdRegionCode = sdRegionCode;
	}

	public String getHrRegionCode() {
		return hrRegionCode;
	}

	public void setHrRegionCode(String hrRegionCode) {
		this.hrRegionCode = hrRegionCode;
	}

	public String getRegionName() {
		return regionName;
	}

	public void setRegionName(String regionName) {
		this.regionName = regionName;
	}

	public String getFranchiserProvince() {
		return franchiserProvince;
	}

	public void setFranchiserProvince(String franchiserProvince) {
		this.franchiserProvince = franchiserProvince;
	}

	public String getFranchiserCity() {
		return franchiserCity;
	}

	public void setFranchiserCity(String franchiserCity) {
		this.franchiserCity = franchiserCity;
	}

	public String getFranchiserDistrict() {
		return franchiserDistrict;
	}

	public void setFranchiserDistrict(String franchiserDistrict) {
		this.franchiserDistrict = franchiserDistrict;
	}

	public String getSaleareaProvince() {
		return saleareaProvince;
	}

	public void setSaleareaProvince(String saleareaProvince) {
		this.saleareaProvince = saleareaProvince;
	}

	public String getSaleareaCity() {
		return saleareaCity;
	}

	public void setSaleareaCity(String saleareaCity) {
		this.saleareaCity = saleareaCity;
	}

	public String getSaleareaDistrict() {
		return saleareaDistrict;
	}

	public void setSaleareaDistrict(String saleareaDistrict) {
		this.saleareaDistrict = saleareaDistrict;
	}

	public java.util.Date getLastUpdateDate() {
		return lastUpdateDate;
	}

	public void setLastUpdateDate(java.util.Date lastUpdateDate) {
		this.lastUpdateDate = lastUpdateDate;
	}

	public String getFlag() {
		return flag;
	}

	public void setFlag(String flag) {
		this.flag = flag;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((franchiserCode == null) ? 0 : franchiserCode.hashCode());
		result = prime * result + ((hrOrgCode == null) ? 0 : hrOrgCode.hashCode());
		result = prime * result + ((masterCustomerCode == null) ? 0 : masterCustomerCode.hashCode());
		result = prime * result + ((saleareaCity == null) ? 0 : saleareaCity.hashCode());
		result = prime * result + ((saleareaDistrict == null) ? 0 : saleareaDistrict.hashCode());
		result = prime * result + ((saleareaProvince == null) ? 0 : saleareaProvince.hashCode());
		result = prime * result + ((sdRegionCode == null) ? 0 : sdRegionCode.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		FranchiserOrgRelationVo other = (FranchiserOrgRelationVo) obj;
		if (franchiserCode == null) {
			if (other.franchiserCode != null)
				return false;
		} else if (!franchiserCode.equals(other.franchiserCode))
			return false;
		if (hrOrgCode == null) {
			if (other.hrOrgCode != null)
				return false;
		} else if (!hrOrgCode.equals(other.hrOrgCode))
			return false;
		if (masterCustomerCode == null) {
			if (other.masterCustomerCode != null)
				return false;
		} else if (!masterCustomerCode.equals(other.masterCustomerCode))
			return false;
		if (saleareaCity == null) {
			if (other.saleareaCity != null)
				return false;
		} else if (!saleareaCity.equals(other.saleareaCity))
			return false;
		if (saleareaDistrict == null) {
			if (other.saleareaDistrict != null)
				return false;
		} else if (!saleareaDistrict.equals(other.saleareaDistrict))
			return false;
		if (saleareaProvince == null) {
			if (other.saleareaProvince != null)
				return false;
		} else if (!saleareaProvince.equals(other.saleareaProvince))
			return false;
		if (sdRegionCode == null) {
			if (other.sdRegionCode != null)
				return false;
		} else if (!sdRegionCode.equals(other.sdRegionCode))
			return false;
		return true;
	}
	

}
